Crate vortex_geo

Crate vortex_geo 

Modules

aggregate_fn
Aggregate functions over geometry columns.
extension
prune
Chunk pruning for spatial filters, using the per-chunk GeometryAabb axis-aligned bounding box (AABB).
scalar_fn
Geometry scalar functions over the native geometry extension types.

Functions

initialize
Set up a session with support for geospatial extension types, encodings and layouts.