Skip to main content Module extension Copy item path Source GeoMetadata Extension metadata that is common to all the geospatial extension types. LineString A line string: geoarrow.linestring, stored as List<Struct<x, y[, z][, m]>> (an ordered path
of vertices). LineStringData A validated LineString array (try_from checks the extension type). MultiLineString A multilinestring: geoarrow.multilinestring, stored as List<List<Struct<x, y[, z][, m]>>>
(line strings of vertices). MultiLineStringData A validated MultiLineString array (try_from checks the extension type). MultiPoint A multipoint: geoarrow.multipoint, stored as List<Struct<x, y[, z][, m]>> (a set of points). MultiPointData A validated MultiPoint array (try_from checks the extension type). MultiPolygon A multipolygon (geoarrow.multipolygon); a single Polygon is a one-element multipolygon. MultiPolygonData A validated MultiPolygon array (try_from checks the extension type). Point A single location: geoarrow.point, stored as Struct<x, y[, z][, m]> of non-nullable f64. PointData Polygon A polygon: geoarrow.polygon, stored as List<List<Struct<x, y[, z][, m]>>> (rings of vertices). PolygonData A validated Polygon array (try_from checks the extension type). WellKnownBinary An extension type for OGC Well-known Binary (WKB) data format. WellKnownBinaryData A typed handle to an ExtensionArray that contains WKB-encoded data. Wkb A reference to a value of well-known binary encoded geometry data. native_geometry_scalar_from_wkb Decode a WKB geometry literal (DuckDB’s wire form for GEOMETRY constants) to its native
Point/Polygon/MultiPolygon scalar. None for unsupported types. Plan-time, one value only.