pub struct WellKnownBinary;Expand description
An extension type for OGC Well-known Binary (WKB) data format.
This is one of the most common formats for sharing of geometry data between analytic systems, used by DuckDB, PostGIS and GeoParquet.