Modules
- aggregate_
fn - Aggregate functions over geometry columns.
- extension
- prune
- Chunk pruning for spatial filters, using the per-chunk
GeometryAabbaxis-aligned bounding box (AABB). - scalar_
fn - Geometry scalar functions over the native geometry extension types.
Functions
- initialize
- Set up a session with support for geospatial extension types, encodings and layouts.